@@ -7,31 +7,27 @@ import os
 import glob
 import copy
 import codecs
+import functools
 import inspect
 import material
 import pymdownx
-import warnings
 from pymdownx.emoji import TWEMOJI_SVG_CDN, add_attriubtes
 import xml.etree.ElementTree as etree  # noqa: N813
-import pkg_resources
 
-EXPECTED_M_VER = (5, 0, 0)
-M_VER = tuple(int(x) for x in pkg_resources.require('mkdocs-material')[0].version.split('.')[:3])
 OPTION_SUPPORT = pymdownx.__version_info__ >= (7, 1, 0)
 RESOURCES = os.path.dirname(inspect.getfile(material))
 
-# Check that we have the expected version running
-if M_VER < EXPECTED_M_VER:  # pragma: no cover
-    warnings.warn(
-        'mkdocs-material-extensions expects a mkdocs-material version of at least {} to work properly'.format(
-            EXPECTED_M_VER
-        )
-    )
-
 
 def _patch_index(options):
     """Patch the given index."""
 
+    icon_locations = options.get('custom_icons', [])[:]
+    icon_locations.append(os.path.join(RESOURCES, '.icons'))
+    return _patch_index_for_locations(tuple(icon_locations))
+
+
+@functools.lru_cache(maxsize=None)
+def _patch_index_for_locations(icon_locations):
     import pymdownx.twemoji_db as twemoji_db
 
     # Copy the Twemoji index
@@ -41,13 +37,10 @@ def _patch_index(options):
         "aliases": copy.deepcopy(twemoji_db.aliases) if not OPTION_SUPPORT else twemoji_db.aliases
     }
 
-    icon_locations = options.get('custom_icons', [])[:]
-    icon_locations.append(os.path.join(RESOURCES, '.icons'))
-
     # Find our icons
     for icon_path in icon_locations:
         norm_base = icon_path.replace('\\', '/') + '/'
-        for result in glob.glob(icon_path.replace('\\', '/') + '/**/*.svg', recursive=True):
+        for result in glob.glob(glob.escape(icon_path.replace('\\', '/')) + '/**/*.svg', recursive=True):
             name = ':{}:'.format(result.replace('\\', '/').replace(norm_base, '', 1).replace('/', '-').lstrip('.')[:-4])
             if name not in index['emoji'] and name not in index['aliases']:
                 # Easiest to just store the path and pull it out from the index
